# GitHub Copilot Instructions

- Follow project conventions and best practices.
- Only generate documentation when explicitly asked.

- After every update make sure to create or update tests to cover the changes.
- After every update make sure to run tests to verify that everything works as expected.
- After every update make sure to run builds to verify that everything builds as expected.

- You are not under a time constraint, so take your time to produce high-quality code.
